@@ -12,6 +12,7 @@ class matching:
 command_list = [        #同指令中越长的匹配词越靠前
     matching(("切换绑定","更换绑定","更改绑定"),"changebind"),
     matching(("查询绑定","绑定查询","绑定列表","查绑定"),"bindlist"),
+    matching(("删除绑定",),"delete_bind"),
     matching(("特殊绑定",),"special_bind"),
     matching(("ship.rank","SHIP.RANK","rank","RANK"),"ship_rank"),
     matching(("bind","BIND","绑定","set","SET"),"bind"),
@@ -25,7 +26,7 @@ nations = [
     matching(("commonwealth","英联邦",),"commonwealth"),
     matching(("europe","欧洲",),"europe"),
     matching(("france","法国",),"france"),
-    matching(("germany","德国",),"germany:"),
+    matching(("germany","德国",),"germany"),
     matching(("italy","意大利",),"italy"),
     matching(("japan","日本",),"japan"),
     matching(("pan_america","泛美",),"pan_america"),
@@ -285,7 +286,7 @@ async def set_recentparams(List):
         InfoRecent_RankData = await set_InfoRecent_RankData(List['shipData'][0])
         winsColor = await set_winColor(List['shipData'][0]['pvpInfo']['wins'])
         damageColor = await set_damageColor(None,List['shipData'][0]['pvpInfo']['damage'])
-        solo_winsColor = await set_winColor(List['shipData'][0]['pvpSoloInfo']['damage'])
+        solo_winsColor = await set_winColor(List['shipData'][0]['pvpSoloInfo']['wins'])
         solo_damageColor = await set_damageColor(None,List['shipData'][0]['pvpSoloInfo']['damage'])
         div2_winsColor = await set_winColor(List['shipData'][0]['pvpTwoInfo']['wins'])
         div2_damageColor = await set_damageColor(None,List['shipData'][0]['pvpTwoInfo']['damage'])
@@ -365,14 +366,16 @@ async def set_shipparams(List):
         damageTopColor = await set_upinfo_color(List['dwpDataVO']['damage'])
         winsTopColor = await set_upinfo_color(List['dwpDataVO']['wins'])
         prTopColor = await set_upinfo_color(List['dwpDataVO']['pr'])
+        winsColor = await set_winColor(List['shipInfo']['wins'])
+        damageColor = await set_damageColor(List['shipInfo']['shipInfo']['shipType'],List['shipInfo']['damage'])
         solo_winsColor = await set_winColor(List['shipSolo']['wins'])
-        solo_damageColor = await set_damageColor(None,List['shipSolo']['damage'])
+        solo_damageColor = await set_damageColor(List['shipInfo']['shipInfo']['shipType'],List['shipSolo']['damage'])
         div2_winsColor = await set_winColor(List['shipTwo']['wins'])
-        div2_damageColor = await set_damageColor(None,List['shipTwo']['damage'])
+        div2_damageColor = await set_damageColor(List['shipInfo']['shipInfo']['shipType'],List['shipTwo']['damage'])
         div3_winsColor = await set_winColor(List['shipThree']['wins'])
-        div3_damageColor = await set_damageColor(None,List['shipThree']['damage'])
+        div3_damageColor = await set_damageColor(List['shipInfo']['shipInfo']['shipType'],List['shipThree']['damage'])
         rank_winsColor = await set_winColor(List['rankSolo']['wins'])
-        rank_damageColor = await set_damageColor(None,List['rankSolo']['damage'])
+        rank_damageColor = await set_damageColor(List['shipInfo']['shipInfo']['shipType'],List['rankSolo']['damage'])
         result = {
             "guild":List['clanInfo']['tag'],
             "userName":List['userName'],
@@ -437,6 +440,8 @@ async def set_shipparams(List):
             "damageTopColor":damageTopColor,
             "winsTopColor":winsTopColor,
             "prTopColor":prTopColor,
+            "winsColor":winsColor,
+            "damageColor":damageColor,
             "solo_winsColor":solo_winsColor,
             "solo_damageColor":solo_damageColor,
             "div2_winsColor":div2_winsColor,
