@@ -61,7 +61,7 @@ async def get_AccountInfo(qqid,info):
             elif params:
                 logger.info(f"{params}")
             else:
-                return '您似乎准备用游戏昵称查询总体水表，请检查参数中是否包含服务器和游戏昵称，以空格区分'
+                return '您似乎准备用游戏昵称查询，请检查参数中是否包含服务器和游戏昵称，以空格区分'
         else:
             return '参数似乎出了问题呢'
         logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
@@ -82,6 +82,8 @@ async def get_AccountInfo(qqid,info):
             return f"{result['message']}\n这是服务器问题，请联系雨季麻麻"
         else:
             return '查询不到对应信息哦~可能是游戏昵称不正确或QQ未绑定'
+    except httpx.ReadTimeout:
+        return '请求超时了，请过会儿再尝试哦~'
     except Exception:
         logger.error(traceback.format_exc())
         return 'wuwuwu出了点问题，请联系麻麻解决'
\ No newline at end of file
